@@ -52,9 +52,9 @@ You shoud also find the complete GPL in the COPYING file accompanying this sourc
 +----------------------------------------------------------------------------+
 */
 #include "hwdrv_apci035.h"
-INT i_WatchdogNbr=0;
-INT i_Temp=0;
-INT i_Flag=1;
+INT i_WatchdogNbr = 0;
+INT i_Temp = 0;
+INT i_Flag = 1;
 /*
 +----------------------------------------------------------------------------+
 | Function   Name   : int i_APCI035_ConfigTimerWatchdog                      |
@@ -109,159 +109,148 @@ INT i_Flag=1;
 |			                                                         |
 +----------------------------------------------------------------------------+
 */
-INT i_APCI035_ConfigTimerWatchdog(comedi_device *dev,comedi_subdevice *s,comedi_insn *insn,lsampl_t *data)
+INT i_APCI035_ConfigTimerWatchdog(comedi_device * dev, comedi_subdevice * s,
+	comedi_insn * insn, lsampl_t * data)
 {
-UINT ui_Status=0;
-UINT ui_Command=0;
-UINT ui_Mode=0;
-i_Temp=0;
-devpriv->tsk_Current=current;
-devpriv->b_TimerSelectMode=data[0];
-i_WatchdogNbr=data[1];
-if(data[0]==0)
-   {
-   ui_Mode=2;
-   }
-else
-   {
-   ui_Mode=0;
-   }  
+	UINT ui_Status = 0;
+	UINT ui_Command = 0;
+	UINT ui_Mode = 0;
+	i_Temp = 0;
+	devpriv->tsk_Current = current;
+	devpriv->b_TimerSelectMode = data[0];
+	i_WatchdogNbr = data[1];
+	if (data[0] == 0) {
+		ui_Mode = 2;
+	} else {
+		ui_Mode = 0;
+	}
 //ui_Command = inl(devpriv->iobase+((i_WatchdogNbr-1)*32)+12);
-ui_Command=0;
+	ui_Command = 0;
 //ui_Command = ui_Command & 0xFFFFF9FEUL;
-outl(ui_Command,devpriv->iobase+((i_WatchdogNbr-1)*32)+12);
-ui_Command=0;
-ui_Command = inl(devpriv->iobase+((i_WatchdogNbr-1)*32)+12);
+	outl(ui_Command, devpriv->iobase + ((i_WatchdogNbr - 1) * 32) + 12);
+	ui_Command = 0;
+	ui_Command = inl(devpriv->iobase + ((i_WatchdogNbr - 1) * 32) + 12);
 /************************/
 /* Set the reload value */
 /************************/
-outl( data[3],devpriv->iobase+((i_WatchdogNbr-1)*32) + 4);
+	outl(data[3], devpriv->iobase + ((i_WatchdogNbr - 1) * 32) + 4);
 /*********************/
 /* Set the time unit */
-/*********************/ 
-outl(data[2],devpriv->iobase+((i_WatchdogNbr-1)*32) + 8);
-if (data[0] == ADDIDATA_TIMER)
-   {
-                 
+/*********************/
+	outl(data[2], devpriv->iobase + ((i_WatchdogNbr - 1) * 32) + 8);
+	if (data[0] == ADDIDATA_TIMER) {
 
-                 /******************************/
-                 /* Set the mode :             */
-                 /* - Disable the hardware     */
-                 /* - Disable the counter mode */
-                 /* - Disable the warning      */
-                 /* - Disable the reset        */
-                 /* - Enable the timer mode    */
-                 /* - Set the timer mode       */
-                 /******************************/
-                
+		 /******************************/
+		/* Set the mode :             */
+		/* - Disable the hardware     */
+		/* - Disable the counter mode */
+		/* - Disable the warning      */
+		/* - Disable the reset        */
+		/* - Enable the timer mode    */
+		/* - Set the timer mode       */
+		 /******************************/
 
-    ui_Command = (ui_Command & 0xFFF719E2UL) | ui_Mode << 13UL | 0x10UL;
+		ui_Command =
+			(ui_Command & 0xFFF719E2UL) | ui_Mode << 13UL | 0x10UL;
 
-   }//if (data[0] == ADDIDATA_TIMER)
- else
-   {
-      if(data[0]==ADDIDATA_WATCHDOG)
-         {           
+	}			//if (data[0] == ADDIDATA_TIMER)
+	else {
+		if (data[0] == ADDIDATA_WATCHDOG) {
 
-                 /******************************/
-                 /* Set the mode :             */
-                 /* - Disable the hardware     */
-                 /* - Disable the counter mode */
-                 /* - Disable the warning      */
-                 /* - Disable the reset        */
-                 /* - Disable the timer mode   */
-                 /******************************/
-                 
+		 /******************************/
+			/* Set the mode :             */
+			/* - Disable the hardware     */
+			/* - Disable the counter mode */
+			/* - Disable the warning      */
+			/* - Disable the reset        */
+			/* - Disable the timer mode   */
+		 /******************************/
 
-            ui_Command = ui_Command & 0xFFF819E2UL;
+			ui_Command = ui_Command & 0xFFF819E2UL;
 
-         } 
-      else 
-         {
-         printk("\n The parameter for Timer/watchdog selection is in error\n");
-         return -EINVAL;
-         }
-    }
-outl(ui_Command,devpriv->iobase+((i_WatchdogNbr-1)*32)+12);
-ui_Command=0;
-ui_Command = inl(devpriv->iobase+((i_WatchdogNbr-1)*32)+12);
+		} else {
+			printk("\n The parameter for Timer/watchdog selection is in error\n");
+			return -EINVAL;
+		}
+	}
+	outl(ui_Command, devpriv->iobase + ((i_WatchdogNbr - 1) * 32) + 12);
+	ui_Command = 0;
+	ui_Command = inl(devpriv->iobase + ((i_WatchdogNbr - 1) * 32) + 12);
 /********************************/
 /* Disable the hardware trigger */
 /********************************/
-ui_Command = ui_Command & 0xFFFFF89FUL;  
- if (data[4] == ADDIDATA_ENABLE)
-    {
+	ui_Command = ui_Command & 0xFFFFF89FUL;
+	if (data[4] == ADDIDATA_ENABLE) {
     /**********************************/
-    /* Set the hardware trigger level */
-    /**********************************/          
-     ui_Command = ui_Command |  ( data[5] << 5);
-    }           
-outl(ui_Command,devpriv->iobase+((i_WatchdogNbr-1)*32)+12);
-ui_Command=0;
-ui_Command = inl(devpriv->iobase+((i_WatchdogNbr-1)*32)+12); 
+		/* Set the hardware trigger level */
+    /**********************************/
+		ui_Command = ui_Command | (data[5] << 5);
+	}
+	outl(ui_Command, devpriv->iobase + ((i_WatchdogNbr - 1) * 32) + 12);
+	ui_Command = 0;
+	ui_Command = inl(devpriv->iobase + ((i_WatchdogNbr - 1) * 32) + 12);
 /*****************************/
 /* Disable the hardware gate */
-/*****************************/   
-ui_Command = ui_Command & 0xFFFFF87FUL; 
-if (data[6] == ADDIDATA_ENABLE)
-   {
+/*****************************/
+	ui_Command = ui_Command & 0xFFFFF87FUL;
+	if (data[6] == ADDIDATA_ENABLE) {
 /*******************************/
 /* Set the hardware gate level */
-/*******************************/             
-   ui_Command = ui_Command |( data[7] << 7);
-   }
-outl(ui_Command,devpriv->iobase+((i_WatchdogNbr-1)*32)+12);           
-ui_Command=0;
-ui_Command = inl(devpriv->iobase+((i_WatchdogNbr-1)*32)+12);             
+/*******************************/
+		ui_Command = ui_Command | (data[7] << 7);
+	}
+	outl(ui_Command, devpriv->iobase + ((i_WatchdogNbr - 1) * 32) + 12);
+	ui_Command = 0;
+	ui_Command = inl(devpriv->iobase + ((i_WatchdogNbr - 1) * 32) + 12);
 /*******************************/
 /* Disable the hardware output */
 /*******************************/
-ui_Command = ui_Command & 0xFFFFF9FBUL;           
+	ui_Command = ui_Command & 0xFFFFF9FBUL;
 /*********************************/
 /* Set the hardware output level */
 /*********************************/
-ui_Command = ui_Command |( data[8] << 2);          
-outl(ui_Command,devpriv->iobase+((i_WatchdogNbr-1)*32)+12); 
-if(data[9]==ADDIDATA_ENABLE)  
-   { 
+	ui_Command = ui_Command | (data[8] << 2);
+	outl(ui_Command, devpriv->iobase + ((i_WatchdogNbr - 1) * 32) + 12);
+	if (data[9] == ADDIDATA_ENABLE) {
    /************************/
-   /* Set the reload value */
-   /************************/         
-   outl (data[11],devpriv->iobase+((i_WatchdogNbr-1)*32) + 24);
+		/* Set the reload value */
+   /************************/
+		outl(data[11],
+			devpriv->iobase + ((i_WatchdogNbr - 1) * 32) + 24);
    /**********************/
-   /* Set the time unite */
-   /**********************/ 
-   outl(data[10],devpriv->iobase+((i_WatchdogNbr-1)*32)+ 28);
-   }
+		/* Set the time unite */
+   /**********************/
+		outl(data[10],
+			devpriv->iobase + ((i_WatchdogNbr - 1) * 32) + 28);
+	}
 
-    ui_Command=0;
-    ui_Command = inl(devpriv->iobase+((i_WatchdogNbr-1)*32)+12);              
+	ui_Command = 0;
+	ui_Command = inl(devpriv->iobase + ((i_WatchdogNbr - 1) * 32) + 12);
  /*******************************/
- /* Disable the hardware output */
- /*******************************/         
-   ui_Command = ui_Command & 0xFFFFF9F7UL;          
+	/* Disable the hardware output */
+ /*******************************/
+	ui_Command = ui_Command & 0xFFFFF9F7UL;
    /*********************************/
-   /* Set the hardware output level */
+	/* Set the hardware output level */
    /*********************************/
- ui_Command = ui_Command |( data[12] << 3);           
- outl(ui_Command,devpriv->iobase+((i_WatchdogNbr-1)*32)+12); 
+	ui_Command = ui_Command | (data[12] << 3);
+	outl(ui_Command, devpriv->iobase + ((i_WatchdogNbr - 1) * 32) + 12);
  /*************************************/
  /**  Enable the watchdog interrupt  **/
- /*************************************/ 
-ui_Command=0;
-ui_Command = inl(devpriv->iobase+((i_WatchdogNbr-1)*32)+12);  
+ /*************************************/
+	ui_Command = 0;
+	ui_Command = inl(devpriv->iobase + ((i_WatchdogNbr - 1) * 32) + 12);
 /*******************************/
 /* Set the interrupt selection */
 /*******************************/
-ui_Status =inl(devpriv->iobase+((i_WatchdogNbr-1)*32) + 16);
+	ui_Status = inl(devpriv->iobase + ((i_WatchdogNbr - 1) * 32) + 16);
 
-ui_Command = (ui_Command & 0xFFFFF9FDUL) |  ( data[13] << 1);
-outl(ui_Command,devpriv->iobase+((i_WatchdogNbr-1)*32)+12); 
+	ui_Command = (ui_Command & 0xFFFFF9FDUL) | (data[13] << 1);
+	outl(ui_Command, devpriv->iobase + ((i_WatchdogNbr - 1) * 32) + 12);
 
-return insn->n;
+	return insn->n;
 }
 
-
 /*
 +----------------------------------------------------------------------------+
 | Function   Name   : int i_APCI035_StartStopWriteTimerWatchdog              |
@@ -289,92 +278,90 @@ return insn->n;
 |					                                                 |
 +----------------------------------------------------------------------------+
 */
-INT i_APCI035_StartStopWriteTimerWatchdog(comedi_device *dev,comedi_subdevice *s,comedi_insn *insn,lsampl_t *data)
+INT i_APCI035_StartStopWriteTimerWatchdog(comedi_device * dev,
+	comedi_subdevice * s, comedi_insn * insn, lsampl_t * data)
 {
-   UINT  ui_Command = 0; 
-   INT i_Count=0;
-      if  (data[0]==1) 
-         { 
-         ui_Command = inl(devpriv->iobase+((i_WatchdogNbr-1)*32)+12);
-         /**********************/
-         /* Start the hardware */
-         /**********************/
-         ui_Command = (ui_Command & 0xFFFFF9FFUL) | 0x1UL;
-         outl(ui_Command,devpriv->iobase+((i_WatchdogNbr-1)*32)+12); 
-         } // if  (data[0]==1)
-      if(data[0]==2)
-         {
-         ui_Command = inl(devpriv->iobase+((i_WatchdogNbr-1)*32)+12); 
-         /***************************/
-         /* Set the trigger command */
-         /***************************/
-         ui_Command = (ui_Command & 0xFFFFF9FFUL) | 0x200UL;
-         outl(ui_Command,devpriv->iobase+((i_WatchdogNbr-1)*32)+12);   
-         } 
-           
-      if (data[0]==0) //Stop The Watchdog 
-         {
-         //Stop The Watchdog
-         ui_Command=0;
-         //ui_Command = inl(devpriv->iobase+((i_WatchdogNbr-1)*32)+12); 
-         //ui_Command = ui_Command & 0xFFFFF9FEUL;
-         outl(ui_Command,devpriv->iobase+((i_WatchdogNbr-1)*32)+12);   
-         } //  if (data[1]==0)
-      if(data[0]==3)//stop all Watchdogs
-        {
-         ui_Command=0; 
-         for(i_Count=1;i_Count<=4;i_Count++)
-            {
-            if(devpriv->b_TimerSelectMode==ADDIDATA_WATCHDOG)
-              {
-               ui_Command=0x2UL;
-              }
-            else
-              {
-              ui_Command = 0x10UL; 
-              } 
-               i_WatchdogNbr=i_Count;
-               outl(ui_Command,devpriv->iobase+((i_WatchdogNbr-1)*32) + 0);
-             }
+	UINT ui_Command = 0;
+	INT i_Count = 0;
+	if (data[0] == 1) {
+		ui_Command =
+			inl(devpriv->iobase + ((i_WatchdogNbr - 1) * 32) + 12);
+	 /**********************/
+		/* Start the hardware */
+	 /**********************/
+		ui_Command = (ui_Command & 0xFFFFF9FFUL) | 0x1UL;
+		outl(ui_Command,
+			devpriv->iobase + ((i_WatchdogNbr - 1) * 32) + 12);
+	}			// if  (data[0]==1)
+	if (data[0] == 2) {
+		ui_Command =
+			inl(devpriv->iobase + ((i_WatchdogNbr - 1) * 32) + 12);
+	 /***************************/
+		/* Set the trigger command */
+	 /***************************/
+		ui_Command = (ui_Command & 0xFFFFF9FFUL) | 0x200UL;
+		outl(ui_Command,
+			devpriv->iobase + ((i_WatchdogNbr - 1) * 32) + 12);
+	}
 
-         } 
-      if(data[0]==4)//start all Watchdogs
-        {
-         ui_Command = 0;
-         for(i_Count=1;i_Count<=4;i_Count++)
-            {
-            if(devpriv->b_TimerSelectMode==ADDIDATA_WATCHDOG)
-              {
-               ui_Command = 0x1UL;
-              }
-            else
-               {
-               ui_Command = 0x8UL;
-               } 
-               i_WatchdogNbr=i_Count;
-	       outl(ui_Command,devpriv->iobase+((i_WatchdogNbr-1)*32) + 0);             
-             } 
-          }
-      if(data[0]==5)//trigger all Watchdogs
-        {
-         ui_Command =0;
-         for(i_Count=1;i_Count<=4;i_Count++)
-            {
-            if(devpriv->b_TimerSelectMode==ADDIDATA_WATCHDOG)
-               {
-               ui_Command=0x4UL;
-               }
-            else
-              {
-              ui_Command = 0x20UL; 
-              } 
-   
-          i_WatchdogNbr=i_Count;
-	      outl(ui_Command,devpriv->iobase+((i_WatchdogNbr-1)*32) + 0);
-           }
-         i_Temp=1;
-         }
-   return insn->n;
+	if (data[0] == 0)	//Stop The Watchdog 
+	{
+		//Stop The Watchdog
+		ui_Command = 0;
+		//ui_Command = inl(devpriv->iobase+((i_WatchdogNbr-1)*32)+12); 
+		//ui_Command = ui_Command & 0xFFFFF9FEUL;
+		outl(ui_Command,
+			devpriv->iobase + ((i_WatchdogNbr - 1) * 32) + 12);
+	}			//  if (data[1]==0)
+	if (data[0] == 3)	//stop all Watchdogs
+	{
+		ui_Command = 0;
+		for (i_Count = 1; i_Count <= 4; i_Count++) {
+			if (devpriv->b_TimerSelectMode == ADDIDATA_WATCHDOG) {
+				ui_Command = 0x2UL;
+			} else {
+				ui_Command = 0x10UL;
+			}
+			i_WatchdogNbr = i_Count;
+			outl(ui_Command,
+				devpriv->iobase + ((i_WatchdogNbr - 1) * 32) +
+				0);
+		}
+
+	}
+	if (data[0] == 4)	//start all Watchdogs
+	{
+		ui_Command = 0;
+		for (i_Count = 1; i_Count <= 4; i_Count++) {
+			if (devpriv->b_TimerSelectMode == ADDIDATA_WATCHDOG) {
+				ui_Command = 0x1UL;
+			} else {
+				ui_Command = 0x8UL;
+			}
+			i_WatchdogNbr = i_Count;
+			outl(ui_Command,
+				devpriv->iobase + ((i_WatchdogNbr - 1) * 32) +
+				0);
+		}
+	}
+	if (data[0] == 5)	//trigger all Watchdogs
+	{
+		ui_Command = 0;
+		for (i_Count = 1; i_Count <= 4; i_Count++) {
+			if (devpriv->b_TimerSelectMode == ADDIDATA_WATCHDOG) {
+				ui_Command = 0x4UL;
+			} else {
+				ui_Command = 0x20UL;
+			}
+
+			i_WatchdogNbr = i_Count;
+			outl(ui_Command,
+				devpriv->iobase + ((i_WatchdogNbr - 1) * 32) +
+				0);
+		}
+		i_Temp = 1;
+	}
+	return insn->n;
 }
 
 /*
@@ -404,38 +391,37 @@ INT i_APCI035_StartStopWriteTimerWatchdog(comedi_device *dev,comedi_subdevice *s
 |			                                                         |
 +----------------------------------------------------------------------------+
 */
-INT i_APCI035_ReadTimerWatchdog(comedi_device *dev,comedi_subdevice *s,comedi_insn *insn,lsampl_t *data)
+INT i_APCI035_ReadTimerWatchdog(comedi_device * dev, comedi_subdevice * s,
+	comedi_insn * insn, lsampl_t * data)
 {
-UINT ui_Status = 0;   // Status register 
- i_WatchdogNbr=insn->unused[0]; 
-              /******************/
-              /* Get the status */
-              /******************/  
-      ui_Status =inl(devpriv->iobase+((i_WatchdogNbr-1)*32) + 16);
+	UINT ui_Status = 0;	// Status register 
+	i_WatchdogNbr = insn->unused[0];
+	      /******************/
+	/* Get the status */
+	      /******************/
+	ui_Status = inl(devpriv->iobase + ((i_WatchdogNbr - 1) * 32) + 16);
       /***********************************/
-      /* Get the software trigger status */
+	/* Get the software trigger status */
       /***********************************/
-      data[0] = ((ui_Status >> 1) & 1); 
+	data[0] = ((ui_Status >> 1) & 1);
       /***********************************/
-      /* Get the hardware trigger status */
+	/* Get the hardware trigger status */
       /***********************************/
-      data[1] =  ((ui_Status >> 2) & 1); 
+	data[1] = ((ui_Status >> 2) & 1);
       /*********************************/
-      /* Get the software clear status */
-      /*********************************/ 
-      data[2] = ((ui_Status >> 3) & 1);
+	/* Get the software clear status */
+      /*********************************/
+	data[2] = ((ui_Status >> 3) & 1);
       /***************************/
-      /* Get the overflow status */
+	/* Get the overflow status */
       /***************************/
-      data[3] = ((ui_Status >> 0) & 1);
-    if  (devpriv->b_TimerSelectMode==ADDIDATA_TIMER) 
-      {
-      data[4]=inl(devpriv->iobase+((i_WatchdogNbr-1)*32) + 0);
-      
-      } //  if  (devpriv->b_TimerSelectMode==ADDIDATA_TIMER) 
-  
-      
-   return insn->n;
+	data[3] = ((ui_Status >> 0) & 1);
+	if (devpriv->b_TimerSelectMode == ADDIDATA_TIMER) {
+		data[4] = inl(devpriv->iobase + ((i_WatchdogNbr - 1) * 32) + 0);
+
+	}			//  if  (devpriv->b_TimerSelectMode==ADDIDATA_TIMER) 
+
+	return insn->n;
 }
 
 /*
@@ -461,20 +447,21 @@ UINT ui_Status = 0;   // Status register
 |			                                                         |
 +----------------------------------------------------------------------------+
 */
-INT i_APCI035_ConfigAnalogInput(comedi_device *dev,comedi_subdevice *s,comedi_insn *insn,lsampl_t *data) 
+INT i_APCI035_ConfigAnalogInput(comedi_device * dev, comedi_subdevice * s,
+	comedi_insn * insn, lsampl_t * data)
 {
-devpriv->tsk_Current=current;
-outl(0x200 | 0, devpriv->iobase+128 + 0x4);
-outl(0, devpriv->iobase+128 + 0);
+	devpriv->tsk_Current = current;
+	outl(0x200 | 0, devpriv->iobase + 128 + 0x4);
+	outl(0, devpriv->iobase + 128 + 0);
 /********************************/
 /* Initialise the warning value */
 /********************************/
-outl(0x300 | 0, devpriv->iobase+128 + 0x4);
-outl((data[0] << 8), devpriv->iobase+128 + 0);
-outl(0x200000UL , devpriv->iobase+128 + 12);
+	outl(0x300 | 0, devpriv->iobase + 128 + 0x4);
+	outl((data[0] << 8), devpriv->iobase + 128 + 0);
+	outl(0x200000UL, devpriv->iobase + 128 + 12);
 
-return insn->n;
-} 
+	return insn->n;
+}
 
 /*
 +----------------------------------------------------------------------------+
@@ -497,31 +484,26 @@ return insn->n;
 |			                                                         |
 +----------------------------------------------------------------------------+
 */
-INT i_APCI035_ReadAnalogInput(comedi_device *dev,comedi_subdevice *s,comedi_insn *insn,lsampl_t *data) 
-{ 
-UINT ui_CommandRegister=0;
+INT i_APCI035_ReadAnalogInput(comedi_device * dev, comedi_subdevice * s,
+	comedi_insn * insn, lsampl_t * data)
+{
+	UINT ui_CommandRegister = 0;
 /******************/
 /*  Set the start */
 /******************/
-ui_CommandRegister =0x80000;  
+	ui_CommandRegister = 0x80000;
  /******************************/
- /* Write the command register */
+	/* Write the command register */
  /******************************/
-outl(ui_CommandRegister, devpriv->iobase+128 + 8);
-              
+	outl(ui_CommandRegister, devpriv->iobase + 128 + 8);
+
 /***************************************/
 /* Read the digital value of the input */
 /***************************************/
-data[0] = inl (devpriv->iobase+ 128 + 28);                           
-return insn->n;
+	data[0] = inl(devpriv->iobase + 128 + 28);
+	return insn->n;
 }
 
-
-
-
-
-
-
 /*
 +----------------------------------------------------------------------------+
 | Function   Name   :  int i_APCI035_Reset(comedi_device *dev)			     |
@@ -537,17 +519,16 @@ return insn->n;
 |			                                                                 |
 +----------------------------------------------------------------------------+
 */
-INT i_APCI035_Reset(comedi_device *dev)
+INT i_APCI035_Reset(comedi_device * dev)
 {
-INT i_Count=0;
-for(i_Count=1;i_Count<=4;i_Count++)
-    {
-     i_WatchdogNbr=i_Count;
-     outl(0x0,devpriv->iobase+((i_WatchdogNbr-1)*32) + 0);//stop all timers
-    }
-outl(0x0 , devpriv->iobase+128 + 12);//Disable the warning delay
+	INT i_Count = 0;
+	for (i_Count = 1; i_Count <= 4; i_Count++) {
+		i_WatchdogNbr = i_Count;
+		outl(0x0, devpriv->iobase + ((i_WatchdogNbr - 1) * 32) + 0);	//stop all timers
+	}
+	outl(0x0, devpriv->iobase + 128 + 12);	//Disable the warning delay
 
- return 0;
+	return 0;
 }
 
 /*
@@ -567,61 +548,53 @@ outl(0x0 , devpriv->iobase+128 + 12);//Disable the warning delay
 |			                                                         |
 +----------------------------------------------------------------------------+
 */
-static void v_APCI035_Interrupt(int irq, void *d) 
-{	
-   comedi_device *dev = d;
-   UINT ui_StatusRegister1 = 0;
-   UINT ui_StatusRegister2=0;
-   UINT ui_ReadCommand =0;
-   UINT ui_ChannelNumber=0;
-   UINT ui_DigitalTemperature=0;
-   if(i_Temp==1)
-       {
-        i_WatchdogNbr=i_Flag;  
-        i_Flag=i_Flag+1;  
-       }     
+static void v_APCI035_Interrupt(int irq, void *d)
+{
+	comedi_device *dev = d;
+	UINT ui_StatusRegister1 = 0;
+	UINT ui_StatusRegister2 = 0;
+	UINT ui_ReadCommand = 0;
+	UINT ui_ChannelNumber = 0;
+	UINT ui_DigitalTemperature = 0;
+	if (i_Temp == 1) {
+		i_WatchdogNbr = i_Flag;
+		i_Flag = i_Flag + 1;
+	}
   /**************************************/
-  /* Read the interrupt status register of temperature Warning */
+	/* Read the interrupt status register of temperature Warning */
   /**************************************/
-   ui_StatusRegister1 = inl(devpriv->iobase+128 + 16);  
+	ui_StatusRegister1 = inl(devpriv->iobase + 128 + 16);
   /**************************************/
-   /* Read the interrupt status register for Watchdog/timer */ 
+	/* Read the interrupt status register for Watchdog/timer */
    /**************************************/
-  
-   ui_StatusRegister2 = inl (devpriv->iobase+((i_WatchdogNbr-1)*32) + 20);
-   
-   if ((((ui_StatusRegister1 ) & 0x8) == 0x8))//Test if warning relay interrupt
-        {
-        /**********************************/
-        /* Disable the temperature warning */
-        /**********************************/
-         ui_ReadCommand = inl (devpriv->iobase+128 + 12);
-         ui_ReadCommand = ui_ReadCommand & 0xFFDF0000UL;
-         outl(ui_ReadCommand , devpriv->iobase+128 + 12);     
+
+	ui_StatusRegister2 =
+		inl(devpriv->iobase + ((i_WatchdogNbr - 1) * 32) + 20);
+
+	if ((((ui_StatusRegister1) & 0x8) == 0x8))	//Test if warning relay interrupt
+	{
+	/**********************************/
+		/* Disable the temperature warning */
+	/**********************************/
+		ui_ReadCommand = inl(devpriv->iobase + 128 + 12);
+		ui_ReadCommand = ui_ReadCommand & 0xFFDF0000UL;
+		outl(ui_ReadCommand, devpriv->iobase + 128 + 12);
       /***************************/
-      /* Read the channel number */
-      /***************************/   
-        ui_ChannelNumber  = inl(devpriv->iobase+128 + 60);
-        /**************************************/
-        /* Read the digital temperature value */
-        /**************************************/
-         ui_DigitalTemperature = inl(devpriv->iobase+128 + 60);  
-         send_sig(SIGIO,devpriv->tsk_Current,0); // send signal to the sample
-        }//if (((ui_StatusRegister1 & 0x8) == 0x8)) 
-           
-   else
-       {
-       if((ui_StatusRegister2 & 0x1) == 0x1)       
-          {
-           send_sig(SIGIO,devpriv->tsk_Current,0); // send signal to the sample     
-          }
-        }//else if (((ui_StatusRegister1 & 0x8) == 0x8))       
-        
-    
-return;
+		/* Read the channel number */
+      /***************************/
+		ui_ChannelNumber = inl(devpriv->iobase + 128 + 60);
+	/**************************************/
+		/* Read the digital temperature value */
+	/**************************************/
+		ui_DigitalTemperature = inl(devpriv->iobase + 128 + 60);
+		send_sig(SIGIO, devpriv->tsk_Current, 0);	// send signal to the sample
+	}			//if (((ui_StatusRegister1 & 0x8) == 0x8)) 
+
+	else {
+		if ((ui_StatusRegister2 & 0x1) == 0x1) {
+			send_sig(SIGIO, devpriv->tsk_Current, 0);	// send signal to the sample     
+		}
+	}			//else if (((ui_StatusRegister1 & 0x8) == 0x8))       
+
+	return;
 }
-
-
-
-
-
