@@ -52,36 +52,36 @@ References:
  * options that are used with comedi_config.
  */
 #include <linux/comedidev.h>
-#include <linux/pci.h> /* for PCI devices */
+#include "comedi_pci.h"
 
 #define PCI6208_DRIVER_NAME 	"adl_pci6208"
 
 /* Board descriptions */
 typedef struct {
 	const char *name;
-	unsigned short dev_id; /* `lspci` will show you this */
+	unsigned short dev_id;	/* `lspci` will show you this */
 	int ao_chans;
 	//int ao_bits;
 } pci6208_board;
 static const pci6208_board pci6208_boards[] = {
 	/*{
-		name	:  "pci6208v",
-		dev_id	:  0x6208,	//not sure
-		ao_chans:  8
-	//,	ao_bits	:  16
-	},
+	   name :  "pci6208v",
+	   dev_id       :  0x6208,      //not sure
+	   ao_chans:  8
+	   //,  ao_bits :  16
+	   },
+	   {
+	   name :  "pci6216v",
+	   dev_id       :  0x6208,      //not sure
+	   ao_chans:  16
+	   //,  ao_bits :  16
+	   }, */
 	{
-		name	:  "pci6216v",
-		dev_id	:  0x6208,	//not sure
-		ao_chans:  16
-	//,	ao_bits	:  16
-	},*/
-	{
-		name	:  "pci6208a",
-		dev_id	:  0x6208,
-		ao_chans:  8
-	//,	ao_bits	:  16
-	}
+	      name:	"pci6208a",
+	      dev_id:	0x6208,
+	      ao_chans:8
+			//,     ao_bits :  16
+		}
 };
 
 /* This is used by modprobe to translate PCI IDs to drivers.  Should
@@ -89,50 +89,52 @@ static const pci6208_board pci6208_boards[] = {
 static struct pci_device_id pci6208_pci_table[] __devinitdata = {
 	//{ PCI_VENDOR_ID_ADLINK, 0x6208, PCI_ANY_ID, PCI_ANY_ID, 0, 0, 0 },
 	//{ PCI_VENDOR_ID_ADLINK, 0x6208, PCI_ANY_ID, PCI_ANY_ID, 0, 0, 0 },
-	{ PCI_VENDOR_ID_ADLINK, 0x6208, PCI_ANY_ID, PCI_ANY_ID, 0, 0, 0 },
-	{ 0 }
+	{PCI_VENDOR_ID_ADLINK, 0x6208, PCI_ANY_ID, PCI_ANY_ID, 0, 0, 0},
+	{0}
 };
+
 MODULE_DEVICE_TABLE(pci, pci6208_pci_table);
 
 /* Will be initialized in pci6208_find device(). */
 #define thisboard ((const pci6208_board *)dev->board_ptr)
 
-typedef struct{
+typedef struct {
 	int data;
-	struct pci_dev *pci_dev; /* for a PCI device */
-	lsampl_t ao_readback[2]; /* Used for AO readback */
-}pci6208_private;
+	struct pci_dev *pci_dev;	/* for a PCI device */
+	lsampl_t ao_readback[2];	/* Used for AO readback */
+} pci6208_private;
 
 #define devpriv ((pci6208_private *)dev->private)
 
-static int pci6208_attach(comedi_device *dev,comedi_devconfig *it);
-static int pci6208_detach(comedi_device *dev);
+static int pci6208_attach(comedi_device * dev, comedi_devconfig * it);
+static int pci6208_detach(comedi_device * dev);
 
 #define pci6208_board_nbr \
 	(sizeof(pci6208_boards) / sizeof(pci6208_board))
 
-static comedi_driver driver_pci6208={
-	driver_name:	PCI6208_DRIVER_NAME,
-	module:		THIS_MODULE,
-	attach:		pci6208_attach,
-	detach:		pci6208_detach,
+static comedi_driver driver_pci6208 = {
+      driver_name:PCI6208_DRIVER_NAME,
+      module:THIS_MODULE,
+      attach:pci6208_attach,
+      detach:pci6208_detach,
 };
+
 COMEDI_INITCLEANUP(driver_pci6208);
 
+static int pci6208_find_device(comedi_device * dev, int bus, int slot);
 static int
-pci6208_find_device(comedi_device *dev, int bus, int slot);
-static int
-pci6208_pci_setup(struct pci_dev *pci_dev, unsigned long *io_base_ptr, int dev_minor);
+pci6208_pci_setup(struct pci_dev *pci_dev, unsigned long *io_base_ptr,
+	int dev_minor);
 
 /*read/write functions*/
-static int pci6208_ao_winsn(comedi_device *dev,comedi_subdevice *s,
-	comedi_insn *insn,lsampl_t *data);
-static int pci6208_ao_rinsn(comedi_device *dev,comedi_subdevice *s,
-	comedi_insn *insn,lsampl_t *data);
+static int pci6208_ao_winsn(comedi_device * dev, comedi_subdevice * s,
+	comedi_insn * insn, lsampl_t * data);
+static int pci6208_ao_rinsn(comedi_device * dev, comedi_subdevice * s,
+	comedi_insn * insn, lsampl_t * data);
 //static int pci6208_dio_insn_bits(comedi_device *dev,comedi_subdevice *s,
-//	comedi_insn *insn,lsampl_t *data);
+//      comedi_insn *insn,lsampl_t *data);
 //static int pci6208_dio_insn_config(comedi_device *dev,comedi_subdevice *s,
-//	comedi_insn *insn,lsampl_t *data);
+//      comedi_insn *insn,lsampl_t *data);
 
 /*
  * Attach is called by the Comedi core to configure the driver
@@ -140,43 +142,46 @@ static int pci6208_ao_rinsn(comedi_device *dev,comedi_subdevice *s,
  * in the driver structure, dev->board_ptr contains that
  * address.
  */
-static int pci6208_attach(comedi_device *dev,comedi_devconfig *it)
+static int pci6208_attach(comedi_device * dev, comedi_devconfig * it)
 {
 	comedi_subdevice *s;
 	int retval;
 	unsigned long io_base;
-	
+
 	printk("comedi%d: pci6208: ", dev->minor);
 
 	retval = alloc_private(dev, sizeof(pci6208_private));
-	if (retval < 0) return retval;
-	
-	retval = pci6208_find_device(dev, it->options[0], it->options[1]);
-	if (retval < 0) return retval;
-	
-	retval = pci6208_pci_setup(devpriv->pci_dev, &io_base, dev->minor);
-	if (retval < 0) return retval;
+	if (retval < 0)
+		return retval;
 
-	dev->iobase=io_base;
+	retval = pci6208_find_device(dev, it->options[0], it->options[1]);
+	if (retval < 0)
+		return retval;
+
+	retval = pci6208_pci_setup(devpriv->pci_dev, &io_base, dev->minor);
+	if (retval < 0)
+		return retval;
+
+	dev->iobase = io_base;
 	dev->board_name = thisboard->name;
-	
+
 /*
  * Allocate the subdevice structures.  alloc_subdevice() is a
  * convenient macro defined in comedidev.h.
  */
-	if(alloc_subdevices(dev, 2)<0)
+	if (alloc_subdevices(dev, 2) < 0)
 		return -ENOMEM;
 
-	s=dev->subdevices+0;
+	s = dev->subdevices + 0;
 	/* analog output subdevice */
-	s->type=COMEDI_SUBD_AO;
-	s->subdev_flags=SDF_WRITABLE; //anything else to add here??
-	s->n_chan=thisboard->ao_chans;
-	s->maxdata=0xffff; //16-bit DAC
-	s->range_table=&range_bipolar10; //this needs to be checked.
+	s->type = COMEDI_SUBD_AO;
+	s->subdev_flags = SDF_WRITABLE;	//anything else to add here??
+	s->n_chan = thisboard->ao_chans;
+	s->maxdata = 0xffff;	//16-bit DAC
+	s->range_table = &range_bipolar10;	//this needs to be checked.
 	s->insn_write = pci6208_ao_winsn;
 	s->insn_read = pci6208_ao_rinsn;
-	
+
 	//s=dev->subdevices+1;
 	/* digital i/o subdevice */
 	//s->type=COMEDI_SUBD_DIO;
@@ -186,13 +191,12 @@ static int pci6208_attach(comedi_device *dev,comedi_devconfig *it)
 	//s->range_table=&range_digital;
 	//s->insn_bits = pci6208_dio_insn_bits;
 	//s->insn_config = pci6208_dio_insn_config;
-	
+
 	printk("attached\n");
 
 	return 1;
 }
 
-
 /*
  * _detach is called to deconfigure a device.  It should deallocate
  * resources.  
@@ -201,36 +205,35 @@ static int pci6208_attach(comedi_device *dev,comedi_devconfig *it)
  * allocated by _attach().  dev->private and dev->subdevices are
  * deallocated automatically by the core.
  */
-static int pci6208_detach(comedi_device *dev)
+static int pci6208_detach(comedi_device * dev)
 {
-	printk("comedi%d: pci6208: remove\n",dev->minor);
-	
-	if(devpriv && devpriv->pci_dev){
-		if(dev->iobase) {
-			pci_release_regions(devpriv->pci_dev);
-			pci_disable_device(devpriv->pci_dev);
+	printk("comedi%d: pci6208: remove\n", dev->minor);
+
+	if (devpriv && devpriv->pci_dev) {
+		if (dev->iobase) {
+			comedi_pci_disable(devpriv->pci_dev);
 		}
 		pci_dev_put(devpriv->pci_dev);
 	}
-	
+
 	return 0;
 }
 
-static int pci6208_ao_winsn(comedi_device *dev,comedi_subdevice *s,
-		comedi_insn *insn,lsampl_t *data)
+static int pci6208_ao_winsn(comedi_device * dev, comedi_subdevice * s,
+	comedi_insn * insn, lsampl_t * data)
 {
-	int i=0, Data_Read;
+	int i = 0, Data_Read;
 	unsigned short chan = CR_CHAN(insn->chanspec);
-	unsigned long invert = 1 << (16-1);
-	unsigned long out_value;	
+	unsigned long invert = 1 << (16 - 1);
+	unsigned long out_value;
 	/* Writing a list of values to an AO channel is probably not
 	 * very useful, but that's how the interface is defined. */
-	for(i=0;i<insn->n;i++){
+	for (i = 0; i < insn->n; i++) {
 		out_value = data[i] ^ invert;
 		/* a typical programming sequence */
-		do{
+		do {
 			Data_Read = (inw(dev->iobase) & 1);
-		}while(Data_Read);	
+		} while (Data_Read);
 		outw(out_value, dev->iobase + (0x02 * chan));
 		devpriv->ao_readback[chan] = out_value;
 	}
@@ -241,13 +244,13 @@ static int pci6208_ao_winsn(comedi_device *dev,comedi_subdevice *s,
 
 /* AO subdevices should have a read insn as well as a write insn.
  * Usually this means copying a value stored in devpriv. */
-static int pci6208_ao_rinsn(comedi_device *dev,comedi_subdevice *s,
-		comedi_insn *insn,lsampl_t *data)
+static int pci6208_ao_rinsn(comedi_device * dev, comedi_subdevice * s,
+	comedi_insn * insn, lsampl_t * data)
 {
 	int i;
 	int chan = CR_CHAN(insn->chanspec);
 
-	for(i=0;i<insn->n;i++)
+	for (i = 0; i < insn->n; i++)
 		data[i] = devpriv->ao_readback[chan];
 
 	return i;
@@ -259,18 +262,18 @@ static int pci6208_ao_rinsn(comedi_device *dev,comedi_subdevice *s,
  * This allows packed reading/writing of the DIO channels.  The
  * comedi core can convert between insn_bits and insn_read/write */
 //static int pci6208_dio_insn_bits(comedi_device *dev,comedi_subdevice *s,
-//	comedi_insn *insn,lsampl_t *data)
+//      comedi_insn *insn,lsampl_t *data)
 //{
-//	if(insn->n!=2)return -EINVAL;
+//      if(insn->n!=2)return -EINVAL;
 
 	/* The insn data is a mask in data[0] and the new data
 	 * in data[1], each channel cooresponding to a bit. */
-//	if(data[0]){
-//		s->state &= ~data[0];
-//		s->state |= data[0]&data[1];
+//      if(data[0]){
+//              s->state &= ~data[0];
+//              s->state |= data[0]&data[1];
 		/* Write out the new digital output lines */
 		//outw(s->state,dev->iobase + SKEL_DIO);
-//	}
+//      }
 
 	/* on return, data[1] contains the value of the digital
 	 * input and output lines. */
@@ -279,52 +282,47 @@ static int pci6208_ao_rinsn(comedi_device *dev,comedi_subdevice *s,
 	 * it was a purely digital output subdevice */
 	//data[1]=s->state;
 
-//	return 2;
+//      return 2;
 //}
 
 //static int pci6208_dio_insn_config(comedi_device *dev,comedi_subdevice *s,
-//	comedi_insn *insn,lsampl_t *data)
+//      comedi_insn *insn,lsampl_t *data)
 //{
-//	int chan=CR_CHAN(insn->chanspec);
+//      int chan=CR_CHAN(insn->chanspec);
 
 	/* The input or output configuration of each digital line is
 	 * configured by a special insn_config instruction.  chanspec
 	 * contains the channel to be changed, and data[0] contains the
 	 * value COMEDI_INPUT or COMEDI_OUTPUT. */
 
-//	if(data[0]==COMEDI_OUTPUT){
-//		s->io_bits |= 1<<chan;
-//	}else{
-//		s->io_bits &= ~(1<<chan);
-//	}
+//      if(data[0]==COMEDI_OUTPUT){
+//              s->io_bits |= 1<<chan;
+//      }else{
+//              s->io_bits &= ~(1<<chan);
+//      }
 	//outw(s->io_bits,dev->iobase + SKEL_DIO_CONFIG);
 
-//	return 1;
+//      return 1;
 //}
 
-static int
-pci6208_find_device(comedi_device *dev, int bus, int slot)
+static int pci6208_find_device(comedi_device * dev, int bus, int slot)
 {
 	struct pci_dev *pci_dev;
 	int i;
-	
-	for(pci_dev = pci_get_device(PCI_ANY_ID, PCI_ANY_ID, NULL); pci_dev != NULL ; 
+
+	for (pci_dev = pci_get_device(PCI_ANY_ID, PCI_ANY_ID, NULL);
+		pci_dev != NULL;
 		pci_dev = pci_get_device(PCI_ANY_ID, PCI_ANY_ID, pci_dev)) {
-		if (pci_dev->vendor == PCI_VENDOR_ID_ADLINK)
-		{
-			for (i= 0; i< pci6208_board_nbr; i++)
-			{
-				if(pci6208_boards[i].dev_id == pci_dev->device)
-				{
+		if (pci_dev->vendor == PCI_VENDOR_ID_ADLINK) {
+			for (i = 0; i < pci6208_board_nbr; i++) {
+				if (pci6208_boards[i].dev_id == pci_dev->device) {
 					// was a particular bus/slot requested?
-					if((bus != 0) || (slot != 0))
-					{
+					if ((bus != 0) || (slot != 0)) {
 						// are we on the wrong bus/slot?
-						if(pci_dev->bus->number
-						   != bus ||
-						   PCI_SLOT(pci_dev->devfn) 
-						   != slot)
-						{
+						if (pci_dev->bus->number
+							!= bus ||
+							PCI_SLOT(pci_dev->devfn)
+							!= slot) {
 							continue;
 						}
 					}
@@ -334,72 +332,59 @@ pci6208_find_device(comedi_device *dev, int bus, int slot)
 			}
 		}
 	}
-	
-	printk ("comedi%d: no supported board found! (req. bus/slot : %d/%d)\n",
-		  dev->minor, bus, slot);
+
+	printk("comedi%d: no supported board found! (req. bus/slot : %d/%d)\n",
+		dev->minor, bus, slot);
 	return -EIO;
 
-found:
-	printk("comedi%d: found %s (b:s:f=%d:%d:%d) , irq=%d\n", 
+      found:
+	printk("comedi%d: found %s (b:s:f=%d:%d:%d) , irq=%d\n",
 		dev->minor,
 		pci6208_boards[i].name,
 		pci_dev->bus->number,
 		PCI_SLOT(pci_dev->devfn),
-		PCI_FUNC(pci_dev->devfn),
-		pci_dev->irq);
+		PCI_FUNC(pci_dev->devfn), pci_dev->irq);
 
 	// TODO: Warn about non-tested boards.
 	//switch(board->device_id)
 	//{
 	//};
-	
+
 	devpriv->pci_dev = pci_dev;
-	
+
 	return 0;
 }
 
-static int 
-pci6208_pci_setup(struct pci_dev *pci_dev, unsigned long *io_base_ptr, int dev_minor)
+static int
+pci6208_pci_setup(struct pci_dev *pci_dev, unsigned long *io_base_ptr,
+	int dev_minor)
 {
 	unsigned long io_base, io_range, lcr_io_base, lcr_io_range;
 
-	// Enable PCI device
-	if (pci_enable_device(pci_dev) < 0) {
-		printk("comedi%d: Failed to enable PCI device\n", dev_minor);
+	// Enable PCI device and request regions
+	if (comedi_pci_enable(pci_dev, PCI6208_DRIVER_NAME) < 0) {
+		printk("comedi%d: Failed to enable PCI device and request regions\n", dev_minor);
 		return -EIO;
 	}
-	
 	// Read local configuration register base address [PCI_BASE_ADDRESS #1].
 	lcr_io_base = pci_resource_start(pci_dev, 1);
 	lcr_io_range = pci_resource_len(pci_dev, 1);
-	  
+
 	printk("comedi%d: local config registers at address 0x%4lx [0x%4lx]\n",
-		dev_minor,
-		lcr_io_base,
-		lcr_io_range);
-	  
+		dev_minor, lcr_io_base, lcr_io_range);
+
 	// Read PCI6208 register base address [PCI_BASE_ADDRESS #2].
-	io_base = pci_resource_start (pci_dev, 2);
-	io_range = pci_resource_end (pci_dev, 2) - io_base +1;
-	
-	printk ("comedi%d: 6208 registers at address 0x%4lx [0x%4lx]\n",
-		dev_minor,
-		io_base,
-		io_range);
-	
-	// Allocate IO ressources	  
-	if (pci_request_regions(pci_dev, PCI6208_DRIVER_NAME) < 0) {
-		printk("comedi%d: I/O port conflict\n",dev_minor);
-		return -EIO;
-	}
-	
+	io_base = pci_resource_start(pci_dev, 2);
+	io_range = pci_resource_end(pci_dev, 2) - io_base + 1;
+
+	printk("comedi%d: 6208 registers at address 0x%4lx [0x%4lx]\n",
+		dev_minor, io_base, io_range);
+
 	*io_base_ptr = io_base;
 	//devpriv->io_range = io_range;
 	//devpriv->is_valid=0;
 	//devpriv->lcr_io_base=lcr_io_base;
 	//devpriv->lcr_io_range=lcr_io_range;
-		
+
 	return 0;
 }
-
-
