@@ -28,68 +28,70 @@
 
 #include "comedi_fc.h"
 
-static void increment_scan_progress( comedi_subdevice *subd, unsigned int num_bytes )
+static void increment_scan_progress(comedi_subdevice * subd,
+	unsigned int num_bytes)
 {
 	comedi_async *async = subd->async;
 	unsigned int scan_length = cfc_bytes_per_scan(subd);
 
 	async->scan_progress += num_bytes;
-	if( async->scan_progress >= scan_length )
-	{
+	if (async->scan_progress >= scan_length) {
 		async->scan_progress %= scan_length;
 		async->events |= COMEDI_CB_EOS;
 	}
 }
 
 /* Writes an array of data points to comedi's buffer */
-unsigned int cfc_write_array_to_buffer( comedi_subdevice *subd, void *data,
-	unsigned int num_bytes )
+unsigned int cfc_write_array_to_buffer(comedi_subdevice * subd, void *data,
+	unsigned int num_bytes)
 {
 	comedi_async *async = subd->async;
 	unsigned int retval;
 
-	if( num_bytes == 0 ) return 0;
+	if (num_bytes == 0)
+		return 0;
 
-	retval = comedi_buf_write_alloc( async, num_bytes );
-	if( retval != num_bytes )
-	{
-		rt_printk( "comedi: buffer overrun\n" );
+	retval = comedi_buf_write_alloc(async, num_bytes);
+	if (retval != num_bytes) {
+		rt_printk("comedi: buffer overrun\n");
 		async->events |= COMEDI_CB_OVERFLOW;
 		return 0;
 	}
 
-	comedi_buf_memcpy_to( async, 0, data, num_bytes);
-	comedi_buf_write_free( async, num_bytes );
-	increment_scan_progress( subd, num_bytes );
+	comedi_buf_memcpy_to(async, 0, data, num_bytes);
+	comedi_buf_write_free(async, num_bytes);
+	increment_scan_progress(subd, num_bytes);
 	async->events |= COMEDI_CB_BLOCK;
 
 	return num_bytes;
 }
 
-unsigned int cfc_read_array_from_buffer( comedi_subdevice *subd, void *data,
-	unsigned int num_bytes )
+unsigned int cfc_read_array_from_buffer(comedi_subdevice * subd, void *data,
+	unsigned int num_bytes)
 {
 	comedi_async *async = subd->async;
 
-	if( num_bytes == 0 ) return 0;
+	if (num_bytes == 0)
+		return 0;
 
 	num_bytes = comedi_buf_read_alloc(async, num_bytes);
-	comedi_buf_memcpy_from( async, 0, data, num_bytes);
-	comedi_buf_read_free( async, num_bytes );
-	increment_scan_progress( subd, num_bytes );
+	comedi_buf_memcpy_from(async, 0, data, num_bytes);
+	comedi_buf_read_free(async, num_bytes);
+	increment_scan_progress(subd, num_bytes);
 	async->events |= COMEDI_CB_BLOCK;
 
 	return num_bytes;
 }
 
-unsigned int cfc_handle_events( comedi_device *dev, comedi_subdevice *subd )
+unsigned int cfc_handle_events(comedi_device * dev, comedi_subdevice * subd)
 {
 	unsigned int events = subd->async->events;
 
-	if( events == 0 ) return events;
+	if (events == 0)
+		return events;
 
-	if( events & ( COMEDI_CB_EOA | COMEDI_CB_ERROR | COMEDI_CB_OVERFLOW ) )
-		subd->cancel( dev, subd );
+	if (events & (COMEDI_CB_EOA | COMEDI_CB_ERROR | COMEDI_CB_OVERFLOW))
+		subd->cancel(dev, subd);
 
 	comedi_event(dev, subd);
 
@@ -107,9 +109,10 @@ static int __init comedi_fc_init_module(void)
 static void __exit comedi_fc_cleanup_module(void)
 {
 }
+
 module_init(comedi_fc_init_module);
 module_exit(comedi_fc_cleanup_module);
 
-EXPORT_SYMBOL( cfc_write_array_to_buffer );
-EXPORT_SYMBOL( cfc_read_array_from_buffer );
-EXPORT_SYMBOL( cfc_handle_events );
+EXPORT_SYMBOL(cfc_write_array_to_buffer);
+EXPORT_SYMBOL(cfc_read_array_from_buffer);
+EXPORT_SYMBOL(cfc_handle_events);
