@@ -7,7 +7,6 @@
 
 #include <linux/version.h>
 
-
 #if LINUX_VERSION_CODE < KERNEL_VERSION(2,4,10)
 #define MODULE_LICENSE(x)
 #endif
@@ -21,14 +20,16 @@
 #if LINUX_VERSION_CODE < KERNEL_VERSION(2,5,0)
 static inline int try_module_get(struct module *module)
 {
-	if( !module ) return 1;
-	__MOD_INC_USE_COUNT( module );
+	if (!module)
+		return 1;
+	__MOD_INC_USE_COUNT(module);
 	return 1;
 }
 static inline void module_put(struct module *module)
 {
-	if( !module ) return;
-	__MOD_DEC_USE_COUNT( module );
+	if (!module)
+		return;
+	__MOD_DEC_USE_COUNT(module);
 }
 #else
 #define MOD_IN_USE (0)
@@ -39,7 +40,3 @@ static inline void module_put(struct module *module)
 #endif
 
 #endif /* _COMPAT_MODULE_H */
-
-
-
-
